/*
 * tut3.c -- SDL-Tutorial, 3. Kapitel
 * NO Copyright (c) by Nicolai 'Prefect' Haehnle
 *
 * Diese Software ist Public Domain.
 */

#include <stdlib.h>
#include <stdio.h>
#include <time.h>

#include <SDL.h>

SDL_Surface *g_pSurfScreen; /* Der Bildschirminhalt */
SDL_Surface *g_pSurfGalaxies; /* galaxien.bmp */

Uint32 g_Black; /* Farbwert schwarz */

/* Wie viele Galaxien sind auf dem Bildschirm? */
#define NUM_GALAXIES		50

struct galaxy {
	int x, y; /* Koordinaten der Galaxie */
	int type; /* Welches Bild wird fr die Galaxien verwendet? */
};

struct galaxy g_Galaxies[NUM_GALAXIES];

/* Erstelle ein Array aus zufllig gewhlten Galaxienpositionen */
void RandBackground()
{
	int i;
	int num_types; /* Anzahl Galaxientypen im Bitmap "galaxien.bmp" */

	num_types = g_pSurfGalaxies->w / 16;

/* Flle das Galaxien-Array mit zufllig gewhlten Werten */
	for(i = 0; i < NUM_GALAXIES; i++) {
		g_Galaxies[i].x = rand() % 640;
		g_Galaxies[i].y = rand() % 480;
		g_Galaxies[i].type = rand() % num_types;
	}
}

/* Zeichne einen Sternenhintergrund auf den Bildschirm */
void DrawBackground()
{
	int i;

	for(i = 0; i < NUM_GALAXIES; i++) {
		SDL_Rect src;
		SDL_Rect dest;

	/* Berechne die Position des Galaxientypbilds im Quellbitmap */
		src.x = g_Galaxies[i].type * 16;
		src.y = 0;
		src.w = 16;
		src.h = 16;

	/* Die Zielkoordinaten werden eingefllt */
		dest.x = g_Galaxies[i].x;
		dest.y = g_Galaxies[i].y;

		SDL_BlitSurface(g_pSurfGalaxies, &src, g_pSurfScreen, &dest);
	}
}

#ifdef _WIN32
#undef main
#endif
int main()
{
	int running;

/* Initialisiere den Zufallszahlengenerator */
	srand(time(0));

/* SDL initialisieren */
	if (SDL_Init(SDL_INIT_VIDEO) < 0) {
		fprintf(stderr, "SDL konnte nicht initialisiert werden: %s\n",
			SDL_GetError());
		exit(1);
	}
	atexit(SDL_Quit);

/* Bildschirmmodus setzen */
	g_pSurfScreen = SDL_SetVideoMode(640, 480, 0, 0);
	if (!g_pSurfScreen) {
		fprintf(stderr, "Konnte Bildschirmmodus nicht setzen: %s\n",
			SDL_GetError());
		exit(1);
	}

/* galaxien.bmp laden */
	g_pSurfGalaxies = SDL_LoadBMP("galaxien.bmp");
	if (!g_pSurfGalaxies) {
		fprintf(stderr, "galaxien.bmp konnte nicht geladen werden: %s\n",
			SDL_GetError());
		exit(1);
	}

/* Galaxienpositionen vorprogrammieren */
	RandBackground();

/* Farbwerte bestimmen */
	g_Black = SDL_MapRGB(g_pSurfScreen->format, 0, 0, 0);

/* Bildschirmhintergrund lschen */
	SDL_FillRect(g_pSurfScreen, 0, g_Black);

/* Sternenhintergrund darstellen */
	DrawBackground();

/* Die nderung mssen wirksam gemacht werden */
	SDL_UpdateRect(g_pSurfScreen, 0, 0, 0, 0);

/* Programmschleife */
	running = 1;
	while(running) {
		SDL_Event event;

		while(SDL_PollEvent(&event)) {
			switch(event.type) {
			case SDL_KEYDOWN:
				running = 0;
				break;
			case SDL_QUIT:
				running = 0;
				break;
			}
		}
	}

/* Unser Bitmap mu freigegeben werden */
	SDL_FreeSurface(g_pSurfGalaxies);

        return 0;
}
